import { NimmstaDevice } from './NimmstaDevice';
import { CommunicationService } from './services/CommunicationService';
import { ActionResponse, IAction } from './models/actions/IAction';
import { GetConnectionCodeResponse } from './models/actions/GetConnectionCodeAction';
import { DeviceFilter, GetDevicesResponse } from './models/actions/GetDevicesAction';
import { DeviceSearchEvent } from './models/events/DeviceSearchEvent';
import { SocketConnectEvent } from './models/events/SocketConnectEvent';
import { SocketDisconnectEvent } from './models/events/SocketDisconnectEvent';
import { ConfigurationBundle } from './models/general/ConfigurationBundle';
import { NIMSubEvent } from './models/events/NIMSubEvent';
import { KeyboardSettings } from './models/actions/UpdateKeyboardSettingsAction';
import { ConnectionManagerSettings } from './models/general/ConnectionManagerSettings';
import { PlatformVersionData } from './models/actions/GetInitialConnectionManagerInfosAction';
import { LEDMode } from './lighttag/models/LEDMode';
export declare class NimmstaConnectionManager {
    private logger;
    currentSocketCount: number;
    communicationService: CommunicationService;
    allDevices: NimmstaDevice[];
    maxConnectedDevices: number;
    readonly maxConnectedLightTagDevices: number;
    generalErrorEvent: NIMSubEvent<string>;
    socketConnectEvent: NIMSubEvent<SocketConnectEvent>;
    socketDisconnectEvent: NIMSubEvent<SocketDisconnectEvent>;
    connectEvent: NIMSubEvent<NimmstaDevice>;
    deviceFoundEvent: NIMSubEvent<DeviceSearchEvent>;
    deviceStartedConnectingEvent: NIMSubEvent<NimmstaDevice>;
    deviceStartedReconnectingEvent: NIMSubEvent<NimmstaDevice>;
    deviceStoppedReconnectingEvent: NIMSubEvent<NimmstaDevice>;
    deviceRemovedEvent: NIMSubEvent<DeviceSearchEvent>;
    gotFocusEvent: NIMSubEvent<unknown>;
    lostFocusEvent: NIMSubEvent<unknown>;
    versions: [PlatformVersionData];
    availableCustomConfiguration?: ConfigurationBundle;
    support: {
        motionTrigger: boolean;
        lightTag(device: NimmstaDevice): boolean;
    };
    private connectCodeCallbacks;
    private connectAddressCallbacks;
    private communicationRetry;
    private communicationTime;
    private isTryingToConnect;
    private isChoosingTool;
    private connectionManagerSettings;
    get connectedDevices(): NimmstaDevice[];
    get devices(): NimmstaDevice[];
    get allowMultiDevice(): boolean;
    set allowMultiDevice(value: boolean);
    get interpretButtonAsMotionTrigger(): boolean;
    set interpretButtonAsMotionTrigger(value: boolean);
    constructor();
    tryConnect(): void;
    private chooseCommunicationTool;
    private fetchInitialInfos;
    private initCommunicationServiceFailed;
    private processEvent;
    registerNimmstaDevice(device: NimmstaDevice): void;
    unregisterNimmstaDevice(device: NimmstaDevice): void;
    unregisterNimmstaDeviceByAddress(address: string): void;
    displayConnectActivity(useTemporaryConnectCode?: boolean): Promise<void>;
    cancelAllConnect(): Promise<void>;
    cancelConnect(addressOrCode: string): Promise<void>;
    cancelSearch(): Promise<void>;
    connectToAddress(address: string, scanTimeout?: number, deviceFoundCallback?: () => void): Promise<NimmstaDevice>;
    connectToConnectionCode(connectionCode: string, scanTimeout?: number, deviceFoundCallback?: () => void): Promise<NimmstaDevice>;
    private sendConnectAction;
    getConnectionCode(): Promise<GetConnectionCodeResponse>;
    getConnectedDevices(): Promise<GetDevicesResponse>;
    getDevices(filter: DeviceFilter): Promise<GetDevicesResponse>;
    private getInitialConnectionManagerInfos;
    updateKeyboardSettings(keyboardSettings: KeyboardSettings): Promise<void>;
    searchForNimmstaDevices(): Promise<void>;
    sendAction(action: IAction): Promise<ActionResponse>;
    private sendVoidAction;
    private updateOrCreateDevice;
    bluetoothCompatibilityModeActivated(active?: boolean): Promise<boolean>;
    canChangeCompatibilityMode(): Promise<boolean>;
    getDeviceWithAddress(address: string): NimmstaDevice;
    checkForDongleUpdate(): Promise<ActionResponse>;
    waitForMultiDeviceUpdate(): Promise<ConnectionManagerSettings>;
    private sendConnectionManagerSettings;
    setDesiredLightTagDevices(desiredDevices: [lightTag: string], ledMode: string | LEDMode): Promise<void>;
    setDesiredLightTagsForGroup(group: string, ledMode: string | LEDMode, desiredDevices: [lightTag: string]): Promise<void>;
    endOfLife(macAddress: string): Promise<void>;
    attachLocation(macAddress: string, location: string): Promise<void>;
    detachLocation(macAddress: string): Promise<void>;
    close(): void;
}
