import { GetDeviceInfoResponse } from './models/actions/GetDeviceInfoAction';
import { EventResponse } from './models/actions/IAction';
import { NimmstaLayout } from './models/layouts/NimmstaLayout';
import { BeeperBurst } from './models/actions/TriggerBeeperBurstAction';
import { LedBurst } from './models/actions/TriggerLEDBurstAction';
import { VibratorBurst } from './models/actions/TriggerVibratorBurstAction';
import { BatteryLevelChangedEvent } from './models/events/BatteryLevelChangedEvent';
import { ErrorEvent } from './models/events/ErrorEvent';
import { ScanEvent } from './models/events/ScanEvent';
import { TouchEvent } from './models/events/TouchEvent';
import { ButtonEvent } from './models/events/ButtonEvent';
import { StartChargingEvent } from './models/events/StartChargingEvent';
import { StopChargingEvent } from './models/events/StopChargingEvent';
import { DisconnectEvent } from './models/events/DisconnectEvent';
import { AimMode, DeviceState, PickingMode, SetDeviceState, TriggerMode } from './models/general/DeviceState';
import { SoftwareUpdateInfo } from './models/actions/ValidateSoftwareUpdateAction';
import { TriggerEvent } from './models/events/TriggerEvent';
import { DoubleTriggerEvent } from './models/events/DoubleTriggerEvent';
import { TripleTriggerEvent } from './models/events/TripleTriggerEvent';
import { SoftwareUpdateProgressEvent } from './models/events/SoftwareUpdateProgressEvent';
import { NIMSubEvent } from './models/events/NIMSubEvent';
import { DigiloTagFoundEvent } from './models/events/DiglioTagFoundEvent';
import { TagEvent } from './models/events/TagEvent';
export declare class NimmstaDevice {
    private logger;
    private nimmstaConnectionManager;
    readonly address: string;
    errorEvent: NIMSubEvent<ErrorEvent>;
    scanEvent: NIMSubEvent<ScanEvent>;
    triggerEvent: NIMSubEvent<TriggerEvent>;
    doubleTriggerEvent: NIMSubEvent<DoubleTriggerEvent>;
    tripleTriggerEvent: NIMSubEvent<TripleTriggerEvent>;
    digiloTagEvent: NIMSubEvent<DigiloTagFoundEvent>;
    touchEvent: NIMSubEvent<TouchEvent>;
    buttonEvent: NIMSubEvent<ButtonEvent>;
    batteryLevelChangedEvent: NIMSubEvent<BatteryLevelChangedEvent>;
    startChargingEvent: NIMSubEvent<StartChargingEvent>;
    stopChargingEvent: NIMSubEvent<StopChargingEvent>;
    disconnectEvent: NIMSubEvent<DisconnectEvent>;
    softwareUpdateProgressEvent: NIMSubEvent<SoftwareUpdateProgressEvent>;
    tagEvent: NIMSubEvent<TagEvent>;
    deviceState?: DeviceState;
    isConnecting: boolean;
    private decoderBoardSettingsValue;
    instanceWasJustCreated: boolean;
    softwareUpdateProgress?: SoftwareUpdateProgressEvent;
    get serialNumber(): string;
    get preferredTriggerMode(): TriggerMode;
    get actualTriggerMode(): TriggerMode;
    get supportMotionTrigger(): boolean;
    get supportsTriggerModeEnabled(): boolean;
    private lastActiveTriggerMode?;
    set preferredTriggerMode(value: TriggerMode);
    get preferredPickingMode(): PickingMode;
    set preferredPickingMode(value: PickingMode);
    get preferredAimMode(): AimMode;
    set preferredAimMode(value: AimMode);
    get barcodeRules(): any;
    set barcodeRules(value: any);
    get prefersReconnect(): boolean;
    set prefersReconnect(value: boolean);
    get reconnectTimeout(): number;
    set reconnectTimeout(value: number);
    get prefersShutdownOnCharge(): boolean;
    set prefersShutdownOnCharge(value: boolean);
    get connected(): boolean;
    get isCharging(): boolean;
    get isSearchingToReconnect(): boolean;
    set decoderBoardSettings(settings: any);
    get decoderBoardSettings(): any;
    get wasReconnected(): boolean;
    constructor(deviceAddress?: string, deviceState?: DeviceState);
    supportsTriggerMode(triggerMode: TriggerMode): boolean;
    private sendAction;
    private sendVoidAction;
    getDeviceInfo(): Promise<GetDeviceInfoResponse>;
    isConnected(): Promise<void>;
    disconnect(shutdown?: boolean): Promise<void>;
    stopReconnecting(): Promise<void>;
    setLayout(layout: NimmstaLayout): Promise<void>;
    setLayoutFor(timeout: number, layout: NimmstaLayout): Promise<void>;
    setXMLLayout(xml: string): Promise<void>;
    setXMLLayoutFor(timeout: number, xml: string): Promise<void>;
    updateLayout(parameters: {
        [index: string]: string;
    }): Promise<void>;
    setLEDColor(red: number, green: number, blue: number): Promise<void>;
    setLEDColorHex(hexStr: string): Promise<void>;
    triggerBursts(ledBurst: LedBurst, vibratorBurst: VibratorBurst, beeperBurst: BeeperBurst): Promise<void>;
    triggerBeeperBurst(beeperBurst: BeeperBurst): Promise<void>;
    triggerBeeperBurstParameters(repeat: number, duration: number, pulseDuration: number, intensity: number): Promise<void>;
    triggerLEDBurst(ledBurst: LedBurst): Promise<void>;
    triggerLEDBurstParameters(repeat: number, duration: number, pulseDuration: number, red: number, green: number, blue: number): Promise<void>;
    triggerSOS(): Promise<void>;
    triggerVibratorBurst(vibratorBurst: VibratorBurst): Promise<void>;
    triggerImager(duration: number): Promise<void>;
    triggerVibratorBurstParameters(repeat: number, duration: number, pulseDuration: number, intensity: number): Promise<void>;
    pressKeys(string: string, virtualKeyCodes: boolean): Promise<void>;
    validateSoftwareUpdate(filePath: string, securityToken: string): Promise<SoftwareUpdateInfo>;
    performSoftwareUpdate(filePath: string, securityToken: string, selectedComponents?: SoftwareUpdateInfo[]): Promise<void>;
    sendDeviceState(settings?: SetDeviceState): Promise<DeviceState>;
    private sendDecoderBoardSettings;
    private setDefaultIntensity;
    processEvent(event: EventResponse): void;
}
