import { SubEvent } from 'sub-events/dist/src/event';
import { Logger, LogLevel } from '../Logger';
import { ActionResponse, IAction, ResponseJson } from '../models/actions/IAction';
import { NimmstaDevice } from '../NimmstaDevice';
export interface RequestJson {
    type: string;
}
export declare class ActionRequest implements RequestJson {
    type: string;
    id: number;
    action: IAction;
    device?: string;
    constructor(id: number, action: IAction, device?: string);
}
export declare class NWLVersionRequest implements RequestJson {
    type: string;
}
export declare class LogRequest implements RequestJson {
    type: string;
    level: LogLevel;
    message: string;
    constructor(logLevel: LogLevel, message: string);
}
export declare class AllowShutdownRequest implements RequestJson {
    type: string;
}
export declare class DisallowShutdownRequest implements RequestJson {
    type: string;
}
export declare abstract class CommunicationService {
    eventReceivedEvent: SubEvent<ResponseJson>;
    connectedToAppEvent: SubEvent<unknown>;
    disconnecedFromAppEvent: SubEvent<unknown>;
    errorEvent: SubEvent<any>;
    requestSendTimeout: number;
    private allowShutdownField;
    get allowShutdown(): boolean;
    set allowShutdown(value: boolean);
    private isConnectedField;
    get isConnected(): boolean;
    set isConnected(value: boolean);
    protected shouldBeConnectedField: boolean;
    get shouldBeConnected(): boolean;
    protected nwlVersion: string;
    protected logger: Logger;
    protected requestId: number;
    protected requestArray: {
        id: number;
        request: ActionRequest;
        resolve: (response: ActionResponse) => void;
        reject: (response: ActionResponse) => void;
    }[];
    abstract initialize(): void;
    abstract sendGeneralAction(action: IAction): Promise<ActionResponse>;
    abstract sendDeviceAction(device: NimmstaDevice, action: IAction): Promise<ActionResponse>;
    abstract sendLog(logLevel: LogLevel, log: string): void;
    abstract sendAllowShutdown(): void;
    abstract tryConnect(): any;
    abstract close(): any;
    abstract isClosed(): any;
    protected processMessage(response: ResponseJson): void;
    protected processActionResponse(id: number, response: ActionResponse): void;
    protected getRequestWithId(id: number): {
        id: number;
        resolve: (response: ActionResponse) => void;
        reject: (response: ActionResponse) => void;
    };
    protected removeRequestWithId(id: number): void;
    protected createPromise(request: ActionRequest): Promise<ActionResponse>;
    protected rejectOpenRequests(error: string, throwable?: string, isIgnorable?: boolean): void;
}
